==> brobygger-li-2.3.2.tar.gz: brobygger-li-2.3.2/scraper/linkedin/companies/schemas.py <==
"""
Title     : Schemas for company json
Objective : Validate the data
Created by: Abdellah Janid
Created on: 6/21/20
"""
# Standard library imports
from typing import Optional, List

# Related third party imports
from pydantic import BaseModel, Field

# Import local applications
from scraper.general_schemas import InitModel, ExtraModel


# noinspection PyMissingOrEmptyDocstring
class CompaniesModel(BaseModel):
    name: str = Field(...)
    industry: Optional[str] = Field(...)
    tagline: Optional[str] = Field(...)
    location: Optional[str] = Field(...)
    followers: Optional[int] = Field(...)
    employees_on_li: Optional[int] = Field(...)
    connections_in_org: Optional[str] = Field(...)
    website: Optional[str] = Field(...)
    url_connections_in_org: Optional[str] = Field(...)
    url_employees: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "name": "name",
            "industry": "industry",
            "tagline": "tagline",
            "location": "location",
            'followers': 'followers',
            'employees_on_li': 'employees_on_li',
            'connections_in_org': 'connections_in_org',
            'website': 'website',
            'url_connections_in_org': 'url_connections_in_org',
            "url_employees": "url_employees"
        }
        allow_population_by_field_name = True


class SimilarCompaniesModel(BaseModel):
    """
    Similar Companies Model
    """
    name: str = Field(...)
    industry: Optional[str] = Field(...)
    url: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Similar Companies'
        fields = {
            'name': 'name',
            'industry': 'industry',
            'url': 'url'
        }
        allow_population_by_field_name = True


class CompaniesSchema(BaseModel):
    """
    Companies Schema
    """
    init: InitModel = Field(...)
    top_card_info: CompaniesModel = Field(...)
    extra: ExtraModel = Field(...)
    # similar_companies: List[SimilarCompaniesModel] = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Companies'
        fields = {
            'init': 'init',
            'top_card_info': 'top_card_info',
            'extra': 'extra'
        }
        extra = 'allow'
        allow_population_by_field_name = True

==> brobygger-li-2.5.1.tar.gz: brobygger-li-2.5.1/scraper/linkedin/companies/schemas.py <==
"""
Title     : Schemas for company json
Objective : Validate the data
Created by: Abdellah Janid
Created on: 6/21/20
"""
# Standard library imports
from typing import Optional, List

# Related third party imports
from pydantic import BaseModel, Field

# Import local applications
from scraper.general_schemas import InitModel, ExtraModel


# noinspection PyMissingOrEmptyDocstring
class CompaniesModel(BaseModel):
    name: str = Field(...)
    industry: Optional[str] = Field(...)
    tagline: Optional[str] = Field(...)
    location: Optional[str] = Field(...)
    followers: Optional[int] = Field(...)
    employees_on_li: Optional[int] = Field(...)
    connections_in_org: Optional[str] = Field(...)
    website: Optional[str] = Field(...)
    url_connections_in_org: Optional[str] = Field(...)
    url_employees: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "name": "name",
            "industry": "industry",
            "tagline": "tagline",
            "location": "location",
            'followers': 'followers',
            'employees_on_li': 'employees_on_li',
            'connections_in_org': 'connections_in_org',
            'website': 'website',
            'url_connections_in_org': 'url_connections_in_org',
            "url_employees": "url_employees"
        }
        allow_population_by_field_name = True


class SimilarCompaniesModel(BaseModel):
    """
    Similar Companies Model
    """
    name: str = Field(...)
    industry: Optional[str] = Field(...)
    followers: Optional[str] = Field(...)
    url: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Similar Companies'
        fields = {
            'name': 'name',
            'industry': 'industry',
            'followers': 'followers',
            'url': 'url'
        }
        allow_population_by_field_name = True


class CompaniesSchema(BaseModel):
    """
    Companies Schema
    """
    init: InitModel = Field(...)
    top_card_info: CompaniesModel = Field(...)
    extra: ExtraModel = Field(...)
    similar_companies: List[SimilarCompaniesModel] = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Companies'
        fields = {
            'init': 'init',
            'top_card_info': 'top_card_info',
            'extra': 'extra',
            'similar_companies':'similar_companies'
        }
        extra = 'allow'
        allow_population_by_field_name = True
